function t = fr_databank (depth,dim,nbfoto,y,save,verbose,draw)
%
% Fr_databank constitue la banque de donnée. Cette fonction effectue 
%   un traitement d'image puis renvoie le vecteur clé publique t, 
%   c'est-à-dire les EigenFaces. 
%		nbfoto : nombre de photo du répertoire courant
%		y : Banque de données vecteur colonne image de taille 
%			[C_Taille,nbfoto]
%		depth : profondeur de couleur des images chargées
%		dim	: dimension [X,Y] d'une image
%			[Teinte min, max , moyenne]
%
%		DEBUG FLAGS
%		save    : mis a 1 cela sauve de l'environnement
%			   (dans le fichier databank.save)
%		verbose : mis a 1 cela affiche les resultats intermédiares
%		draw	: mis a 1 cela affiche les EigenFace en fin
%
%
%       Auteur  : Mathieu Deschamps
%                 mathdesc@yahoo.fr
%       Date    : 11/02/2004 
%       IUT de Caen -- Licence Pro. M.C.A
%


yc=y-ones(dim(1)*dim(2),nbfoto)*depth/2;
if (verbose==1)
	v=cov(yc)
else
	v=cov(yc);
end
if (verbose==1)
	[b,l]=eig(v)
else
	[b,l]=eig(v);
end
  	t = yc*b;
if (size(t)!=size(yc)) 
 	printf("Erreur lors du traitement : taille incohérente"); 
end
if (save==1)
	save "databank.save";
end
printf("Banque de données EigenFace constituée\n");
if (draw==1)
	imshow(reshape(t,dim(1),nbfoto*dim(2)));
end 
